==> block_dictionary_moodle25_2013061800.zip: dictionary/lang/fr/block_dictionary.php <==
<?php

/**
 * *************************************************************************
 * *                           Pop-up Dictionary                          **
 * *************************************************************************
 * @package     block                                                     **
 * @subpackage  dictionary                                                **
 * @name        dictionary                                                **
 * @copyright   oohoo.biz                                                 **
 * @link        http://oohoo.biz                                          **
 * @author      Patrick Thibaudeau                                        **
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later  **
 * *************************************************************************
 * ************************************************************************ */
$string['activated'] = 'Dictionnaire utilisé :';
$string['add'] = 'Ajouter un dictionnaire';
$string['dictionary'] = 'Dictionnaire Pop-up';
$string['dictionary:addinstance'] = 'Ajouter un nouveau bloc dictionnaire popup';
$string['dictionaryinstructions'] = 'Insérer une URL pour chaque champ d\'URL. Si le mot recherché n\'est pas à la fin de l\'URL, il est possible d\'ajouter un paramètre "#WORD#" qui sera remplacé par le mot au moment de la requête.<br><i>Exemple : http://www.larousse.fr/#WORD#/autre_param</i>';
$string['dictionaryname'] = 'Nom du dictionnaire ';
$string['dictionaryurl'] = 'Adresse URL du dictionnaire';
$string['documentation'] = 'Guide utilisateur';
$string['edit'] = 'Modifier votre dictionnaire';
$string['instructions'] = 'Pour activer le dictionnaire, double-cliquez sur un mot du texte';
$string['modify'] = 'Modifier votre dictionnaire:';
$string['nodictionary'] = 'Aucun dictionnaire sélectionné';
$string['popup'] = 'Forcer le dictionnaire à s\'ouvrir dans une popup à la place d\'un onglet du navigateur';
$string['pluginname'] = 'Dictionaire popup';
$string['select'] = 'Sélectionner un dictionnaire';
$string['selecteddictionary'] = 'Dictionnaire utilisé :';
$string['submit'] = 'Sauvegarder';
$string['unknown_dictionary'] = 'Dictionnaire inconnu';

==> block_dictionary_moodle28_2014122400.zip: dictionary/lang/fr/block_dictionary.php <==
<?php

/**
 * *************************************************************************
 * *                           Pop-up Dictionary                          **
 * *************************************************************************
 * @package     block                                                     **
 * @subpackage  dictionary                                                **
 * @name        dictionary                                                **
 * @copyright   oohoo.biz                                                 **
 * @link        http://oohoo.biz                                          **
 * @author      Patrick Thibaudeau                                        **
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later  **
 * *************************************************************************
 * ************************************************************************ */
$string['activated'] = 'Dictionnaire utilisé :';
$string['add'] = 'Ajouter un dictionnaire';
$string['dictionary'] = 'Dictionnaire Pop-up';
$string['dictionary:addinstance'] = 'Ajouter un nouveau bloc dictionnaire popup';
$string['course_list:myaddinstance'] = 'Ajouter un nouveau bloc dictionnaire popup à ma page d\accueil';
$string['dictionaryinstructions'] = 'Insérer une URL pour chaque champ d\'URL. Si le mot recherché n\'est pas à la fin de l\'URL, il est possible d\'ajouter un paramètre "#WORD#" qui sera remplacé par le mot au moment de la requête.<br><i>Exemple : http://www.larousse.fr/#WORD#/autre_param</i>';
$string['dictionaryname'] = 'Nom du dictionnaire ';
$string['dictionaryurl'] = 'Adresse URL du dictionnaire';
$string['documentation'] = 'Guide utilisateur';
$string['edit'] = 'Modifier votre dictionnaire';
$string['instructions'] = 'Pour activer le dictionnaire, double-cliquez sur un mot du texte';
$string['modify'] = 'Modifier votre dictionnaire:';
$string['nodictionary'] = 'Aucun dictionnaire sélectionné';
$string['popup'] = 'Forcer le dictionnaire à s\'ouvrir dans une popup à la place d\'un onglet du navigateur';
$string['pluginname'] = 'Dictionaire popup';
$string['select'] = 'Sélectionner un dictionnaire';
$string['selecteddictionary'] = 'Dictionnaire utilisé :';
$string['submit'] = 'Sauvegarder';
$string['unknown_dictionary'] = 'Dictionnaire inconnu';
